[ARVADOS] updated: 6c2c6780ec231d5a080878a8c1b7b106c5629483

Git user git at public.curoverse.com
Wed Feb 24 21:52:49 EST 2016


Summary of changes:
 apps/workbench/app/views/jobs/_show_log.html.erb   |  4 +-
 apps/workbench/config/application.default.yml      |  4 +-
 apps/workbench/test/integration/websockets_test.rb | 24 ++++-----
 sdk/python/setup.py                                |  3 +-
 services/api/test/fixtures/collections.yml         | 11 ++++
 services/datamanager/collection/collection.go      | 58 +++++++++++++++++++---
 6 files changed, 80 insertions(+), 24 deletions(-)

       via  6c2c6780ec231d5a080878a8c1b7b106c5629483 (commit)
       via  fbd0963c235b6f7d488c5748c772af8c5f636280 (commit)
       via  e5659d21c942c7c315fc33668717329d1487e6c6 (commit)
       via  210d00c923268ceeb7f551874b0e8d0a51654610 (commit)
       via  cdad40f38151c5d678f13787853f361566fbcd43 (commit)
       via  58e1942ff008780d88a3e512dd7806c6a3b975a6 (commit)
       via  23cf2d8b1245c4594bf13b5904e8b72600645d0f (commit)
       via  ec3ff9b42a2b6a5d50603aced6275110fdc90912 (commit)
       via  45ee6988e990ec0c808d3a64b7b0c4a5f864a5ec (commit)
       via  bbd85b230ccd208ef942792109fed1c9161f9429 (commit)
       via  3091c9c336ddca217b14745142f9473a489f42de (commit)
       via  5b63028ebd8fc936cc6d5bcaa7773cc2a745b3f4 (commit)
      from  320f479b1af2a8fb5233415e18e93582d50df848 (commit)

Those revisions listed above that are new to this repository have
not appeared on any other notification email; so we list those
revisions in full, below.


commit 6c2c6780ec231d5a080878a8c1b7b106c5629483
Author: radhika <radhika at curoverse.com>
Date:   Wed Feb 24 21:52:23 2016 -0500

    5694: remove the extra white space in log tab display.

diff --git a/apps/workbench/app/views/jobs/_show_log.html.erb b/apps/workbench/app/views/jobs/_show_log.html.erb
index 68a07ef..02ad2b7 100644
--- a/apps/workbench/app/views/jobs/_show_log.html.erb
+++ b/apps/workbench/app/views/jobs/_show_log.html.erb
@@ -7,8 +7,8 @@
 
 <div id="event_log_div"
      class="arv-log-event-listener arv-log-event-handler-append-logs arv-job-log-window"
-     data-object-uuid="<%= @object.uuid %>" >
-  <%= @object.stderr_log_lines(Rails.configuration.running_job_log_lines_to_fetch).join("\n") %>
+     data-object-uuid="<%= @object.uuid %>"
+  ><%= @object.stderr_log_lines(Rails.configuration.running_job_log_records_to_fetch).join("\n") %>
 </div>
 
 <%# Applying a long throttle suppresses the auto-refresh of this
diff --git a/apps/workbench/config/application.default.yml b/apps/workbench/config/application.default.yml
index ab0deff..5400deb 100644
--- a/apps/workbench/config/application.default.yml
+++ b/apps/workbench/config/application.default.yml
@@ -273,6 +273,6 @@ common:
   # The default setting (false) is appropriate for a multi-user site.
   trust_all_content: false
 
-  # Maximum number of historic log lines of a running job to fetch
+  # Maximum number of historic log records of a running job to fetch
   # and display in the Log tab, while subscribing to web sockets.
-  running_job_log_lines_to_fetch: 2000
+  running_job_log_records_to_fetch: 2000
diff --git a/apps/workbench/test/integration/websockets_test.rb b/apps/workbench/test/integration/websockets_test.rb
index a2300b7..655ad92 100644
--- a/apps/workbench/test/integration/websockets_test.rb
+++ b/apps/workbench/test/integration/websockets_test.rb
@@ -212,14 +212,14 @@ class WebsocketTest < ActionDispatch::IntegrationTest
     assert_in_epsilon value, datum.to_f
   end
 
-  test "test running job with just a few previous log lines" do
+  test "test running job with just a few previous log records" do
     Thread.current[:arvados_api_token] = @@API_AUTHS["admin"]['api_token']
     job = Job.where(uuid: api_fixture("jobs")['running']['uuid']).results.first
     visit page_with_token("admin", "/jobs/#{job.uuid}")
 
     api = ArvadosApiClient.new
 
-    # Create just one old log line
+    # Create just one old log record
     api.api("logs", "", {log: {
                 object_uuid: job.uuid,
                 event_type: "stderr",
@@ -227,11 +227,11 @@ class WebsocketTest < ActionDispatch::IntegrationTest
 
     click_link("Log")
 
     # Expect "all" historic log lines because we have less than
     # default Rails.configuration.running_job_log_lines_to_fetch count
     assert_text 'Historic log message'
 
-    # Create new log line and expect it to show up in log tab
+    # Create new log record and expect it to show up in log tab
     api.api("logs", "", {log: {
                 object_uuid: job.uuid,
                 event_type: "stderr",
@@ -239,8 +239,8 @@ class WebsocketTest < ActionDispatch::IntegrationTest
     assert_text 'Log message after subscription'
   end
 
-  test "test running job with too many previous log lines" do
-    Rails.configuration.running_job_log_lines_to_fetch = 5
+  test "test running job with too many previous log records" do
+    Rails.configuration.running_job_log_records_to_fetch = 5
 
     Thread.current[:arvados_api_token] = @@API_AUTHS["admin"]['api_token']
     job = Job.where(uuid: api_fixture("jobs")['running']['uuid']).results.first
@@ -249,8 +249,8 @@ class WebsocketTest < ActionDispatch::IntegrationTest
 
     api = ArvadosApiClient.new
 
-    # Create Rails.configuration.running_job_log_lines_to_fetch + 1 log lines
-    (0..Rails.configuration.running_job_log_lines_to_fetch).each do |count|
+    # Create Rails.configuration.running_job_log_records_to_fetch + 1 log records
+    (0..Rails.configuration.running_job_log_records_to_fetch).each do |count|
       api.api("logs", "", {log: {
                 object_uuid: job.uuid,
                 event_type: "stderr",
@@ -260,14 +260,14 @@ class WebsocketTest < ActionDispatch::IntegrationTest
     # Go to log tab, which results in subscribing to websockets
     click_link("Log")
 
     # Expect all but the first historic log lines,
     # because that was one too many than fetch count.
-    (1..Rails.configuration.running_job_log_lines_to_fetch).each do |count|
+    (1..Rails.configuration.running_job_log_records_to_fetch).each do |count|
       assert_text "Old log message #{count}"
     end
     assert_no_text 'Old log message 0'
 
-    # Create one more log line after subsription
+    # Create one more log record after subscription
     api.api("logs", "", {log: {
                 object_uuid: job.uuid,
                 event_type: "stderr",

commit fbd0963c235b6f7d488c5748c772af8c5f636280
Merge: 320f479 e5659d2
Author: radhika <radhika at curoverse.com>
Date:   Wed Feb 24 09:34:39 2016 -0500

    Merge branch 'master' into 5694-running-job-log


-----------------------------------------------------------------------
@@ -227,11 +227,11 @@ class WebsocketTest < ActionDispatch::IntegrationTest
     click_link("Log")
 
-    # Expect "all" historic log lines because we have less than
-    # default Rails.configuration.running_job_log_lines_to_fetch count
+    # Expect "all" historic log records because we have less than
+    # default Rails.configuration.running_job_log_records_to_fetch count
     assert_text 'Historic log message'
 
@@ -260,14 +260,14 @@ class WebsocketTest < ActionDispatch::IntegrationTest
     click_link("Log")
 
-    # Expect all but the first historic log lines,
+    # Expect all but the first historic log records,
     # because that was one too many than fetch count.


hooks/post-receive
-- 




More information about the arvados-commits mailing list